@@ -34,7 +34,7 @@ enum fnc_diff_flag {
 	FNC_DIFF_ANSI_COLOR	= (1 << 13)
 #define FNC_DIFF_CONTEXT_EX	(((uint64_t)0x04) << 32) /* allow 0 context */
 #define FNC_DIFF_CONTEXT_MASK	((uint64_t)0x0000ffff)	 /* default context */
-#define FNC_DIFF_WIDTH_MASK	((uint64_t)0x00ff0000)	 /* SBS column width */
+#define FNC_DIFF_WIDTH_MASK	((uint64_t)0xffff0000)	 /* SBS column width */
 };
 
 enum line_type {
@@ -98,21 +98,21 @@ int fnc_diff_text(const fsl_buffer *, const fsl_buffer *, fsl_output_f, void *,
     enum line_type **, size_t *, uint64_t *, short, short, int);
 
 /*
- * Compute and save to the int array pointer in out parameter 1 the array of
- * copy/delete/insert triples that describes the sequence of changes to convert
- * the file in fsl_buffer parameter 2 to the file in fsl_buffer parameter 3.
- * Diff format and related options are set via flags passed in int parameter 4.
+ * Assign to the double pointer to int out parameter 1 the copy/delete/insert
+ * triples array describing the sequence of changes to convert the contents of
+ * fsl_buffer parameter 2 to those of fsl_buffer parameter 3. Callers assume
+ * ownership of the dynamically allocated triples, which is terminated with
+ * three contiguous zero sentinel values. Formatting options are set via the
+ * bitwise OR of enum fnc_diff_flag values passed in int parameter 4.
+ * Each triple of integers means:
+ *   T[0,3,6,..,n-3] (copy):   number of lines both buffers have in common
+ *   T[1,4,7,..,n-2] (delete): number of lines found only in buffer 1
+ *   T[2,5,8,..,n-1] (insert): number of lines found only in buffer 2
+ * Triples repeat until all lines from both buffers are consumed.
+ * The array is terminated with a sentinel triple of three zeros: { 0,0,0 }
  */
 int fnc_diff_text_raw(int **, const fsl_buffer *, const fsl_buffer *, int);
 
-/*
- * Return the number of columns required to draw to the screen the char pointer
- * in parameter 1 by expanding any tabs and accounting for unicode continuation
- * bytes. Short parameter 2 may either be the byte size of the string or less
- * than zero, in which case the string length will be computed with strlen(3).
- */
-unsigned short etcount(const char *, unsigned short);
-
 /*
  * Save the line_type specified in parameter 3 to the nth index denoted by
  * the size_t pointer in parameter 2 of the line_type array in parameter 1.
